#!/usr/bin/perl

#
# schedule_nagios_downtime.pl version 1.0
# -------------------------------------------------------------------------
#  Schedule via command line a downtime for a host and service in nagios.
#  This script can be used as a sample for further improvement and features.
#  Run with -h arg to get the execution howto.
#
#  Author: Patrick Zambelli
#  http://www.neteye-blog.it/about/
# -------------------------------------------------------------------------
#
# LICENSE
#
# This file is part of GPLv3.
#
# This code is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation.
#
# This script is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License;
# if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# --------------------------------------------------------------------------



use strict;
use POSIX;

my $cgi_path = "http://127.0.0.1/neteye/cgi-bin/cmd.cgi";
my $USER = "root";
my $PASSWD = "secret";


# Do not edit below this line #

if ( $#ARGV < 1 ) {

	print "\nIt is required to pass the arguments of Host and service to schedule for downtime.\n";
	&usage();
	
}

sub usage {

	print "./schedule_nagios_downtime.pl <nagios host> <nagios service> [<comment> <seconds of downtime>]\n";
	print "Default comment is 'downtime schedule' seconds\n\n";
	print "Default downtime schedule is 3600 seconds\n\n";
	print "./schedule_nagios_downtime.pl srv_mysql 'SERVICE: mysql' 3600\n\n";
	exit(3);
}


my $host = shift @ARGV;
my $service = shift @ARGV;
my $comment = shift @ARGV;
my $length = shift @ARGV;

unless ($length ) {
	$length = 3600;
}

if (length($comment) < 1 ){
	$comment = "Downtime+schedule";
}

my $startTime = time();
my $endTime = $startTime + $length;

my $nagios_start = POSIX::strftime("%m-%d-%Y %H:%M:00", localtime($startTime));
my $nagios_end = POSIX::strftime("%m-%d-%Y %H:%M:00", localtime($endTime));

 
$nagios_start =~ s@:@%3A@g;
$nagios_start =~ s@-@%2D@g;
$nagios_start =~ s@ @%20@g;

$nagios_end =~ s@:@%3A@g;
$nagios_end =~ s@-@%2D@g;
$nagios_end =~ s@ @%20@g;


my $URL = $cgi_path.'?fixed=1&cmd_typ=55&cmd_mod=2&start_time=' .  $nagios_start . '&end_time=' . $nagios_end . '&host=' . $host . '&com_author=' . $service . '&com_data='.$comment.'&btnSubmit=Commit';

my $cmd = "/usr/bin/wget --quiet --user=".$USER." --password=".$PASSWD." -O /tmp/nagios_downtime.html '$URL'";
#print "CMD: ".$cmd."\n";

open ( L, ">>/tmp/nagios_downtime.log" );

print L `$cmd`;

close L;
